# decider

## Table of Contents

- installation
- compiling
- tests
- help

<a name="installation"></a>

## How do I set up my rust toolchain?

see [Installing Rust](https://doc.rust-lang.org/book/ch01-01-installation.html#installation)
I used this method, after having installed with `brew install rustup-init` or `brew install rust` and getting warnings.

<a name="compiling"></a>

## How do I build?

`cargo build` builds the library

<a name="tests"></a>

## How do I run tests?

`cargo test` runs the tests

<a name="help"></a>

## Where do I go for help?

Ask the experiments team, in #experiments, but probably you won't be here if you aren't already in that team, so ping matt-it's probably his fault.
